@@ -5,12 +5,14 @@ from time import strftime
 
 import nlp2
 from flask import Flask, request, Response
+from flask_caching import Cache
 from flask_cors import CORS
 from gevent.pywsgi import WSGIServer
 import json
-from .util import NumpyEncoder
+from nlp2go.util import NumpyEncoder
 
 logger = logging.getLogger(__name__)
+cache = Cache(config={'CACHE_TYPE': 'simple'})
 
 
 class Server:
@@ -30,24 +32,35 @@ class Server:
             return error_dict
 
     def make_app(self, models, model_detail) -> Flask:
-        app = Flask(__name__)  # pylint: disable=invalid-name
+        app = Flask(__name__)
+        cache.init_app(app)
+
+        def make_cache_key():
+            return str(request.json) + str(request.full_path)
 
         @app.route('/api/<path>', methods=['POST'])
+        @cache.cached(timeout=3600, key_prefix=make_cache_key)
         def predict(path) -> Response:
+            print("api request", path, request.json)
             if path in models:
-                result_dict = models[path].predict(request.json, enable_input_panel=False)
-                return Response(json.dumps({'result': result_dict['result']}, ensure_ascii=False, cls=NumpyEncoder,
+                pred_json = {}
+                for k, v in request.json.items():
+                    pred_json[k + "_component"] = v
+                result_dict = models[path].predict(pred_json)
+                response_json = json.dumps(result_dict, ensure_ascii=False, cls=NumpyEncoder,
                                            indent=4,
-                                           sort_keys=True))
+                                           sort_keys=True)
+                return Response(response_json)
             else:
                 raise self.ServerError("parameter not found", 404)
 
         @app.route('/api/config', methods=['GET'])
         def config() -> Response:
             try:
-                return Response(json.dumps(model_detail, ensure_ascii=False, cls=NumpyEncoder,
+                response_json = json.dumps(model_detail, ensure_ascii=False, cls=NumpyEncoder,
                                            indent=4,
-                                           sort_keys=True))
+                                           sort_keys=True)
+                return Response(response_json)
             except:
                 raise self.ServerError("parameter not found", 404)
 
